@@ -18,7 +18,6 @@ from oslo_utils import timeutils
 
 from zun.common import exception
 from zun.common import policy
-from zun.common import utils
 
 
 class RequestContext(context.RequestContext):
@@ -93,7 +92,8 @@ class RequestContext(context.RequestContext):
                       'auth_token_info': self.auth_token_info,
                       'password': self.password,
                       'all_projects': self.all_projects,
-                      'timestamp': utils.strtime(self.timestamp) if
+                      'timestamp': self.timestamp.strftime(
+                          "%Y-%m-%dT%H:%M:%S.%f") if
                       hasattr(self, 'timestamp') else None
                       })
         return value
